summaryrefslogtreecommitdiffstats
path: root/source/n/samba/doinst.sh
diff options
context:
space:
mode:
Diffstat (limited to 'source/n/samba/doinst.sh')
-rw-r--r--source/n/samba/doinst.sh33
1 files changed, 29 insertions, 4 deletions
diff --git a/source/n/samba/doinst.sh b/source/n/samba/doinst.sh
index eb2b0b58c..ff09d3161 100644
--- a/source/n/samba/doinst.sh
+++ b/source/n/samba/doinst.sh
@@ -10,8 +10,33 @@ config() {
fi
# Otherwise, we leave the .new copy for the admin to consider...
}
-config etc/rc.d/rc.samba.new
+preserve_perms() {
+ NEW="$1"
+ OLD="$(dirname ${NEW})/$(basename ${NEW} .new)"
+ if [ -e ${OLD} ]; then
+ cp -a ${OLD} ${NEW}.incoming
+ cat ${NEW} > ${NEW}.incoming
+ mv ${NEW}.incoming ${NEW}
+ fi
+ config ${NEW}
+}
+
config etc/samba/lmhosts.new
-# This won't be needed. The point here is to preserve the permissions of the existing
-# file, if there is one. I don't see major new development happening in rc.samba... ;-)
-rm -f etc/rc.d/rc.samba.new
+preserve_perms etc/rc.d/rc.samba.new
+
+# Commented out 2014-09-15 just in case we do need to change this.
+## This won't be needed. The point here is to preserve the permissions of the existing
+## file, if there is one. I don't see major new development happening in rc.samba... ;-)
+#rm -f etc/rc.d/rc.samba.new
+
+# Since /etc/samba/private/ has moved to /var/lib/samba/private, migrate any
+# important files if possible:
+if [ -d etc/samba/private -a -d var/lib/samba/private ]; then
+ for file in etc/samba/private/* ; do
+ if [ -r "$file" -a ! -r "var/lib/samba/private/$(basename $file)" ]; then
+ mv "$file" var/lib/samba/private
+ fi
+ done
+ # Might as well try to eliminate this directory, since it should be empty:
+ rmdir etc/samba/private 1> /dev/null 2> /dev/null
+fi